<?php

namespace app\admin\controller\asset;

use app\admin\validate\asset\HouseTypeValidate;
use app\controller\Curd;
use app\model\Asset;
use support\exception\BusinessException;
use support\Request;
use support\Response;

class HouseTypeController extends Curd
{
    public function __construct()
    {
        $this->model = new Asset();
        $this->validate = true;
        $this->validateClass = new HouseTypeValidate();
    }

    public function select(Request $request): Response
    {
        [$where, $format, $limit, $field, $order] = $this->selectInput($request);
        $order = $request->get('order', 'desc');
        $field = $field ?? 'asset_addtimes';
        $query = $this->doSelect($where, $field, $order);
        return $this->doFormat($query, $format, $limit);
    }

    public function afterQuery($items)
    {
        foreach ($items as &$item) {
            $assetHouseJson = json_decode($item->asset_house_json, true);
            if (!empty($assetHouseJson['floor_plan'])) {
                $assetHouseJson['floor_plan'] = getenv('STORAGE_DOMAIN') . $assetHouseJson['floor_plan'];
                $item->asset_house_json = $assetHouseJson;
            }
            $item->asset_json = json_decode($item->asset_json, true);
        }

        return $items;
    }

    /**
     * @Desc 提交数据处理
     * @Author Gorden
     * @Date 2024/3/6 9:11
     *
     * @param Request $request
     * @return array
     * @throws \support\exception\BusinessException
     */
    protected function insertInput(Request $request): array
    {
        $data = $this->inputFilter($request->post());
        $data['asset_id'] = 'AE' . date('YmdHis') . random_string(6, 'up');
        if (!empty($request->post('floor_plan'))) {
            $data['asset_house_json'] = json_encode(['floor_plan' => str_replace(getenv('STORAGE_DOMAIN'), '', $request->post('floor_plan'))]);
        }
        if (empty($request->post('asset_house_address'))) {
            $data['asset_json'] = json_encode(['address' => $request->post('asset_house_address')]);
        }

        return $data;
    }

    protected function updateInput(Request $request): array
    {
        $primary_key = $this->model->getKeyName();
        $id = $request->post($primary_key);
        $data = $this->inputFilter($request->post());
        $model = $this->model->find($id);
        if (!$model) {
            throw new BusinessException('记录不存在', 2);
        }

        if (!empty($request->post('floor_plan'))) {
            $data['asset_house_json'] = json_encode(['floor_plan' => str_replace(getenv('STORAGE_DOMAIN'), '', $request->post('floor_plan'))]);
        }
        if (empty($request->post('asset_house_address'))) {
            $data['asset_json'] = json_encode(['address' => $request->post('asset_house_address')]);
        }

        unset($data[$primary_key]);
        return [$id, $data];
    }
}