<?php

namespace app\admin\controller\order;

use app\admin\validate\coupon\CouponValidate;
use app\admin\validate\device\DeviceValidate;
use app\admin\validate\order\OrderExpressValidate;
use app\admin\validate\order\OrderValidate;
use app\controller\Curd;
use app\model\Coupon;
use app\model\Device;
use app\model\Order;
use app\model\OrderExpress;
use app\model\OrderSheet;
use app\model\SysSerial;
use support\Db;
use support\exception\BusinessException;
use support\Redis;
use support\Request;
use support\Response;

class WholeController extends Curd
{
    public function __construct()
    {
        $this->model = new Order();
        $this->validate = true;
        $this->validateClass = new OrderValidate();
    }

    /**
     * @Desc 列表
     * @Author Gorden
     * @Date 2024/3/28 15:01
     *
     * @param Request $request
     * @return Response
     * @throws \support\exception\BusinessException
     */
    public function select(Request $request): Response
    {
        [$where, $format, $limit, $field, $order] = $this->selectInput($request);
        $order = $request->get('order', 'desc');
        $field = $field ?? 'order_addtimes';
        if (!empty($where['order_status_system']) && $where['order_status_system'] == 'RETURN') {
            unset($where['order_status_system']);
            $where['order_category'] = 'RETURN';
        }
        $query = $this->doSelect($where, $field, $order);
        return $this->doFormat($query, $format, $limit);
    }

    /**
     * @Desc 订单商品详情
     * @Author Gorden
     * @Date 2024/3/29 8:50
     *
     * @param Request $request
     * @return Response
     */
    public function sheet(Request $request)
    {
        $orderId = $request->get('order_id');
        $orderSheet = OrderSheet::with([
            'member' => function ($query) {
                $query->select('member_id', 'member_mobile');
            },
            'goods' => function ($query) {
                $query->select('goods_id', 'goods_name', 'goods_cover', 'goods_market_price', 'goods_sales_price');
            },
        ])->where('join_sheet_order_id', $orderId)
            ->get()
            ->toArray();
        foreach ($orderSheet as &$item) {
            $item['goods']['goods_cover'] = getenv('STORAGE_DOMAIN') . $item['goods']['goods_cover'];
        }

        $order = Order::where('order_id', $orderId)->first();
        $data = [
            'order' => $order,
            'sheet' => $orderSheet
        ];

        return json_success('', $data);
    }

//    protected function updateInput(Request $request): array
//    {
//        $primary_key = $this->model->getKeyName();
//        $id = $request->post($primary_key);
//        $data = $this->inputFilter($request->post());
//        $data['coupon_begindate'] = strtotime($data['coupon_begindate']);
//        $data['coupon_enddate'] = strtotime($data['coupon_enddate']);
//        $model = $this->model->find($id);
//        if (!$model) {
//            throw new BusinessException('记录不存在', 2);
//        }
//        unset($data[$primary_key]);
//        return [$id, $data];
//    }

    public function delivery(Request $request)
    {
        if (!Order::where('order_id', $request->post('order_id'))->where('order_status_system', 'SENDING')->exists()) {
            return json_fail('订单状态异常');
        }

        // 验证
        $validate = new OrderExpressValidate();
        if (!$validate->scene('delivery')->check($request->post())) {
            return json_fail($validate->getError());
        }
        try {
            Db::beginTransaction();
            // 该订单状态
            Order::where('order_id', $request->post('order_id'))->update(['order_status_system' => 'RECVING', 'order_status_storage' => 'EXPRESSING']);
            // 订单包含的产品
            $sheet = OrderSheet::where('join_sheet_order_id', $request->post('order_id'))
                ->select('join_sheet_goods_id')
                ->get();
            // 入配送记录表
            $params = $request->post();
            $model = new OrderExpress();
            $model->join_express_order_id = $params['order_id'];
            $model->order_express_goods = $sheet;
            $model->order_express_type = $params['order_express_type'];
            $model->order_express_code = $params['order_express_code'];
            $model->order_express_city = $params['order_express_city'];
            $model->order_express_address = $params['order_express_address'];
            $model->order_express_mobile = $params['order_express_mobile'];
            $model->order_express_telephone = $params['order_express_telephone'] ?? null;
            $model->order_express_person = $params['order_express_person'] ?? null;
            $model->order_express_remark = $params['order_express_remark'] ?? null;
            $model->order_express_addtimes = time();
            $model->save();

            Db::commit();

            return json_success('发货成功');
        } catch (\Exception $e) {
            Db::rollBack();

            return json_fail('发货失败');
        }
    }
}