<?php

namespace app\admin\controller\sys_manage;

use app\admin\validate\sys_manage\AdvValidate;
use app\admin\validate\sys_manage\ArticleValidate;
use app\admin\validate\sys_manage\ContentValidate;
use app\controller\Curd;
use app\model\Adv;
use app\model\Article;
use app\model\Content;
use support\exception\BusinessException;
use support\Request;
use support\Response;

class QuestionController extends Curd
{
    public function __construct()
    {
        $this->model = new Content();
        $this->validate = true;
        $this->validateClass = new ContentValidate();
    }

    /** 列表
     * @Desc
     * @Author Gorden
     * @Date 2024/3/5 10:00
     *
     * @param Request $request
     * @return Response
     * @throws \support\exception\BusinessException
     */
    public function select(Request $request): Response
    {
        [$where, $format, $limit, $field, $order] = $this->selectInput($request);
        $where['content_category'] = 'WELLNESSQUESTION';
        $order = $request->get('order', 'desc');
        $field = $field ?? 'content_sort';
        $query = $this->doSelect($where, $field, $order);
        return $this->doFormat($query, $format, $limit);
    }

    public function afterQuery($items)
    {
        foreach ($items as &$item) {
            if (!empty($item->content_config_json)) {
                $contentConfigJson = json_decode($item->content_config_json, true);
                $questionArray = [];
                foreach ($contentConfigJson as $question) {
                    $questionArray[] = [
                        [
                            'label' => '序号',
                            'value' => $question['field'],
                        ],
                        [
                            'label' => '题目',
                            'value' => $question['question'],
                        ]
                    ];
                }
                $item->content_config_json = $questionArray;
            }else{
                $item->content_config_json = [];
            }
        }

        return $items;
    }

    /**
     * @Desc
     * @Author Gorden
     * @Date 2024/3/27 10:24
     *
     * @param Request $request
     * @return array
     * @throws \support\exception\BusinessException
     */
    protected function insertInput(Request $request): array
    {
        $data = $this->inputFilter($request->post());
        $data['content_category'] = 'WELLNESSQUESTION';
        $contentConfigJson = [];
        if (!empty($request->post('question'))) {
            $questions = $request->post('question');
            foreach ($questions as $question) {
                if (!empty($question[1]['value'])){
                    $contentConfigJson[] = [
                        'field' => $question[0]['value'],
                        'question' => $question[1]['value'],
                    ];
                }
            }
            usort($contentConfigJson, function ($a, $b) {
                return $a['field'] - $b['field'];
            });

            $data['content_config_json'] = json_encode($contentConfigJson);
        }

        return $data;
    }

    protected function updateInput(Request $request): array
    {
        $primary_key = $this->model->getKeyName();
        $id = $request->post($primary_key);
        $data = $this->inputFilter($request->post());
        $model = $this->model->find($id);
        if (!$model) {
            throw new BusinessException('记录不存在', 2);
        }
        $contentConfigJson = [];
        if (!empty($request->post('question'))) {
            $questions = $request->post('question');
            foreach ($questions as $question) {
                $contentConfigJson[] = [
                    'field' => $question[0]['value'],
                    'question' => $question[1]['value'],
                ];
            }
            usort($contentConfigJson, function ($a, $b) {
                return $a['field'] - $b['field'];
            });

            $data['content_config_json'] = json_encode($contentConfigJson);
        }
        unset($data[$primary_key]);
        return [$id, $data];
    }
}